@@ -2,12 +2,6 @@ package Panda::Install::Payload;
 use strict;
 use warnings;
 
-=head1 NAME
-
-Panda::Install::Payload - Manager for module's payload.
-
-=cut
-
 my %module_info;
 
 sub data_dir {
@@ -80,20 +74,4 @@ sub module_version {
     return $v || 0;
 }
 
-=head1 FUNCTIONS
-
-=head4 payload_dir($module)
-
-Returns directory where the payload of module $module is located or undef if $module didn't install any payload.
-
-=head1 AUTHOR
-
-Pronin Oleg <syber@crazypanda.ru>, Crazy Panda, CP Decision LTD
-
-=head1 LICENSE
-
-You may distribute this code under the same terms as Perl itself.
-
-=cut
-
-1;
+1;
\ No newline at end of file
